/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { GroupDescriptor } from '@progress/kendo-data-query';
import { WorkbookOptions } from '@progress/kendo-ooxml';
import { WorkbookSheetRowCellBorderBottom } from '@progress/kendo-ooxml';
import { WorkbookSheetRowCellBorderLeft } from '@progress/kendo-ooxml';
import { WorkbookSheetRowCellBorderRight } from '@progress/kendo-ooxml';
import { WorkbookSheetRowCellBorderTop } from '@progress/kendo-ooxml';

/**
 * The options for the Excel Export cell.
 */
declare interface CellOptions {
    /**
     * Sets the background color of the cell.
     * Supports hex CSS-like values that start with `"#"`. For example, `"#ff00ff"`.
     */
    background?: string;
    /**
     * The style information for the bottom border of the cell.
     */
    borderBottom?: WorkbookSheetRowCellBorderBottom;
    /**
     * The style information for the left border of the cell.
     */
    borderLeft?: WorkbookSheetRowCellBorderLeft;
    /**
     * The style information for the top border of the cell.
     */
    borderTop?: WorkbookSheetRowCellBorderTop;
    /**
     * The style information for the right border of the cell.
     */
    borderRight?: WorkbookSheetRowCellBorderRight;
    /**
     * If set to `true`, renders the cell value in bold.
     */
    bold?: boolean;
    /**
     * The text color of the cell.
     * Supports hex CSS-like values that start with `"#"`. For example, `"#ff00ff"`.
     */
    color?: string;
    /**
     * Sets the font that is used to display the cell value.
     */
    fontFamily?: string;
    /**
     * Sets the font size in pixels.
     */
    fontSize?: number;
    /**
     * Sets the format that Excel uses to display the cell value.
     * For more information, refer to the page on
     * [supported Excel formats](https://support.office.com/en-us/article/Create-or-delete-a-custom-number-format-78f2a361-936b-4c03-8772-09fab54be7f4).
     */
    format?: string;
    /**
     * If set to `true`, renders the cell value in italics.
     */
    italic?: boolean;
    /**
     * Sets the horizontal alignment of the cell value.
     * The supported values are:
     * * `"left"`
     * * `"center"`
     * * `"right"`
     */
    textAlign?: 'left' | 'center' | 'right';
    /**
     * If set to `true`, underlines the cell value.
     */
    underline?: boolean;
    /**
     * If set to `true`, wraps the cell value.
     */
    wrap?: boolean;
    /**
     * Sets the vertical alignment of the cell value.
     * The supported values are:
     * * `"top"`
     * * `"center"`
     * * `"bottom"`
     */
    verticalAlign?: 'top' | 'center' | 'bottom';
}

/**
 * @hidden
 */
declare interface ColumnBase {
    /**
     * @hidden
     */
    children?: any;
    /**
     * The options of the column header cell.
     */
    headerCellOptions?: CellOptions;
    /**
     * Sets the visibility of the column.
     *
     * @default false
     */
    hidden?: boolean;
    /**
     * @hidden
     */
    level?: number;
    /**
     * Toggles the locked (frozen) state of the column.
     *
     * @default false
     */
    locked?: boolean;
    /**
     * The title of the column.
     */
    title?: string;
    /**
     * The width of the column in pixels.
     */
    width?: number | string;
}

/**
 * Represents the props of the KendoVue ExcelExportColumnProps component.
 */
export declare interface ExcelExportColumnOptions extends ColumnBase {
    /**
     * The options of the column data cells.
     */
    cellOptions?: CellOptions;
    /**
     * The field to which the column is bound.
     */
    field?: string;
    /**
     * The options of the column footer cell.
     */
    footerCellOptions?: CellOptions;
    /**
     * The column footer. Can be a function or a Vue component.
     */
    footer?: Function;
    /**
     * The options of the column group footer cells.
     */
    groupFooterCellOptions?: CellOptions;
    /**
     * The footer of the group. Can be a function or a Vue component.
     */
    groupFooter?: Function;
    /**
     * The options of the column group header cells.
     */
    groupHeaderCellOptions?: CellOptions;
    /**
     * The header of the group. Can be a function or a Vue component.
     */
    groupHeader?: Function;
}

/**
 * Represents the return type of ExcelExportExportEvent.
 */
export declare type ExcelExportExportEvent = {
    dataURL?: string;
    options?: ExcelExportOptions;
};

/**
 * Represents the props of the KendoVue ExcelExport component.
 */
export declare interface ExcelExportOptions {
    /**
     * You can pass the columns through the props of the component.
     * If both the columns prop and the child column components are presented,
     * the columns from props will be used.
     */
    columns?: ExcelExportColumnOptions[] | any[];
    /**
     * The creator of the workbook.
     */
    creator?: string;
    /**
     * The exported data.
     * If grouped, the data must be structured as described by the
     * [`GroupResult`]({% slug api_kendo-data-query_groupresult %}) option of the Kendo UI Data Query component.
     */
    data?: any[];
    /**
     * The date on which the workbook is created.
     * The default value is `new Date()`.
     */
    date?: Date;
    /**
     * Enables or disables the column filtering in the Excel file.
     */
    filterable?: boolean;
    /**
     * Specifies the name of the file that is exported to Excel.
     *
     * @default "Export.xlsx"
     */
    fileName?: string;
    /**
     * If set to `true`, the content is forwarded to `proxyURL`
     * even if the browser supports the saving of files locally.
     */
    forceProxy?: boolean;
    /**
     * The exported data groups.
     * The groups must be compatible with the
     * [`GroupDescriptor`]({% slug api_kendo-data-query_groupdescriptor %}) option of the
     * Kendo UI Data Query component.
     */
    group?: GroupDescriptor[];
    /**
     * The options of the cells that are inserted before the header cells
     * to align the headers and the column values (when the data is grouped).
     */
    headerPaddingCellOptions?: CellOptions;
    /**
     * The options of the cells that are inserted before the data, group, and footer cells
     * to indicate the group hierarchy (when the data is grouped).
     */
    paddingCellOptions?: CellOptions;
    /**
     * The URL of the server-side proxy which will stream the file to the end user.
     * When the browser is not capable of saving files locally&mdash;for example,
     * Internet Explorer 9 and earlier, and Safari&mdash;a proxy is used.
     * The implementation of the server-side proxy has to be done by you.
     * The proxy receives a POST request with the following parameters in the request body:
     * - `contentType`&mdash;The MIME type of the file.
     * - `base64`&mdash;The base-64 encoded file content.
     * - `fileName`&mdash;The file name, as requested by the caller.
     * The proxy is expected to return the decoded file with the **Content-Disposition**
     * header set to `attachment; filename="<fileName.xslx>"`.
     */
    proxyURL?: string;
    /**
     * If set to `rtl`, the Excel file will be rendered in the right-to-left mode.
     */
    dir?: string;
    /**
     * If set to true the data will be exported as a tree based on the `level` property of each data record.
     */
    hierarchy?: boolean;
    /**
     * Enables or disables collapsible (grouped) rows in the exported file.
     */
    collapsible?: boolean;
    /**
     * Triggered after the export is complete.
     */
    onExportComplete?: (event: ExcelExportExportEvent) => void;
}

/**
 * @hidden
 */
export declare const isWorkbookOptions: (value: any) => boolean;

/**
 * @hidden
 */
export declare function saveExcel(exportOptions: ExcelExportOptions): void;

/**
 * @hidden
 */
export declare const toDataURL: (options: WorkbookOptions) => Promise<string>;

/**
 * @hidden
 */
export declare const workbookOptions: (options: ExcelExportOptions) => WorkbookOptions;


export * from "@progress/kendo-ooxml";

export { }
